View source: R/assert_function.R
| assert_function | R Documentation |
Evaluate condition and return error message if condition not satisfied.
assert_function(condition, msg)
condition |
a logical expresssion (e.g. is.null(test_variable)) |
msg |
the error message returned if the condition is not met. |
No return value, called for side effects.
assert_function(1==2,"Incorrect inequality")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.